#
# spec file for package python-azure-mgmt-datafactory
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-mgmt-datafactory
Version:        9.0.0
Release:        1.1
Summary:        Microsoft Azure Data Factory Management Client Library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-mgmt-datafactory/azure-mgmt-datafactory-%{version}.tar.gz
Source1:        LICENSE.txt
BuildRequires:  %{python_module azure-mgmt-nspkg >= 3.0.0}
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-mgmt-nspkg >= 3.0.0
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-typing_extensions >= 4.6.0
Requires:       (python-azure-common >= 1.1 with python-azure-common < 2.0.0)
Requires:       (python-azure-mgmt-core >= 1.3.2 with python-azure-mgmt-core < 2.0.0)
Requires:       (python-isodate >= 0.6.1 with python-isodate < 1.0.0)
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-mgmt-datafactory < 5.0.0
%endif
BuildArch:      noarch

%python_subpackages

%description
This is the Microsoft Azure Data Factory Management Client Library.

Azure Resource Manager (ARM) is the next generation of management APIs that
replace the old Azure Service Management (ASM).

This package has been tested with Python 2.7, 3.5, 3.6 and 3.7.

%prep
%setup -q -n azure-mgmt-datafactory-%{version}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-mgmt-datafactory-%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/mgmt/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/mgmt/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{python_sitelib}/azure/mgmt/datafactory
%{python_sitelib}/azure_mgmt_datafactory-*.dist-info

%changelog
* Tue Aug 27 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 9.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri Jun  7 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 8.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon May 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Apr 29 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 7.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Apr  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 6.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
- Use modern RPM macros to express version dependencies
* Fri Jan 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 5.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Nov 22 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 4.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove unzip package from BuildRequires
- Switch source archive format to TAR.GZ
- Update Requires from setup.py
* Mon Mar 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 3.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Feb 21 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 3.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Nov 22 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.10.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Mon Oct 24 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.9.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Oct 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.8.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Sep 13 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.8.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Sat Jun 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.7.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Mon May 30 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.6.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri May 13 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.5.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Apr 19 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.4.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Mar  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.3.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Feb 16 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.2.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Jan 13 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Mon Nov 29 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Oct 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Mar 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Sun Jan 10 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename HISTORY.rst to CHANGELOG.md in %%files section
- Rename README.rst to README.md in %%files section
- Update Requires from setup.py
* Fri Dec 18 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.15.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Mon Nov 23 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.14.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Sep  8 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.13.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Aug 27 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.12.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename HISTORY.rst to CHANGELOG.md in %%files section
- Rename README.rst to README.md in %%files section
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.8.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Drop patches to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + amd_drop-compatible-releases-operator.patch
  + amd_drop-extras-require.patch
- Update %%description from setup.py
* Fri Apr 12 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.7.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Add patch to drop extras_require field from setup.py,
  required for SLES12 as the setuptools version is too old
  + amd_drop-extras-require.patch
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Refresh patches for new version
  + amd_drop-compatible-releases-operator.patch
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Update %%description from setup.py
- Update BuildRequires and Requires from setup.py
* Wed Apr 11 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.6.0
* Wed Mar  7 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.5.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Move LICENSE.txt from %%doc to %%license section
- Refresh patches for new version
  + amd_drop-compatible-releases-operator.patch
- Update %%description from setup.py
* Wed Jan 24 2018 adrian.glaubitz@suse.com
- Initial build
  + Version 0.3.0
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + amd_drop-compatible-releases-operator.patch
